@@ -79,6 +79,10 @@ def build_options(**options):
         "sourcedir": None,
         "DOPACKAGES": [],
     }
+    if options['arch'] == False:
+        options['arch'] = None
+    if type(options['package']) is str:
+        options['package'] = [ options['package'] ]
     built_options = default_options
     built_options.update(options)
     return type("Options", (object,), built_options)
@@ -238,6 +242,7 @@ class DebHelper:
             unlink(s)
         os.symlink(p, s)
 
+
     # Policy says that if the link is all within one toplevel
     # directory, it should be relative. If it's between
     # top level directories, leave it absolute.
@@ -479,6 +484,8 @@ class DebHelper:
 
     def process_and_move_files(self, *files):
         for pkg in self.packages:
+            if self.options.package is not None and pkg not in self.options.package:
+                continue
             if self.is_udeb(pkg):
                 continue
             if  pkg not in self.options.DOPACKAGES:
